@@ -16,6 +16,7 @@ import sys
 from typing import IO, Any, Dict, List, Type, Union
 
 from botocore.client import ClientMeta
+from botocore.response import StreamingBody
 
 from .literals import SortOrderTypeType
 from .paginator import ListSecretsPaginator
@@ -81,7 +82,7 @@ class Exceptions:
 
 class SecretsManagerClient:
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.98/reference/services/secretsmanager.html#SecretsManager.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/secretsmanager.html#SecretsManager.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client.html)
     """
 
@@ -90,13 +91,13 @@ class SecretsManagerClient:
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.98/reference/services/secretsmanager.html#SecretsManager.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/secretsmanager.html#SecretsManager.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client.html#can_paginate)
         """
 
     def cancel_rotate_secret(self, *, SecretId: str) -> CancelRotateSecretResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.98/reference/services/secretsmanager.html#SecretsManager.Client.cancel_rotate_secret)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/secretsmanager.html#SecretsManager.Client.cancel_rotate_secret)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client.html#cancel_rotate_secret)
         """
 
@@ -107,20 +108,20 @@ class SecretsManagerClient:
         ClientRequestToken: str = None,
         Description: str = None,
         KmsKeyId: str = None,
-        SecretBinary: Union[bytes, IO[bytes]] = None,
+        SecretBinary: Union[bytes, IO[bytes], StreamingBody] = None,
         SecretString: str = None,
         Tags: List["TagTypeDef"] = None,
         AddReplicaRegions: List[ReplicaRegionTypeTypeDef] = None,
         ForceOverwriteReplicaSecret: bool = None
     ) -> CreateSecretResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.98/reference/services/secretsmanager.html#SecretsManager.Client.create_secret)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/secretsmanager.html#SecretsManager.Client.create_secret)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client.html#create_secret)
         """
 
     def delete_resource_policy(self, *, SecretId: str) -> DeleteResourcePolicyResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.98/reference/services/secretsmanager.html#SecretsManager.Client.delete_resource_policy)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/secretsmanager.html#SecretsManager.Client.delete_resource_policy)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client.html#delete_resource_policy)
         """
 
@@ -132,13 +133,13 @@ class SecretsManagerClient:
         ForceDeleteWithoutRecovery: bool = None
     ) -> DeleteSecretResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.98/reference/services/secretsmanager.html#SecretsManager.Client.delete_secret)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/secretsmanager.html#SecretsManager.Client.delete_secret)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client.html#delete_secret)
         """
 
     def describe_secret(self, *, SecretId: str) -> DescribeSecretResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.98/reference/services/secretsmanager.html#SecretsManager.Client.describe_secret)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/secretsmanager.html#SecretsManager.Client.describe_secret)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client.html#describe_secret)
         """
 
@@ -150,7 +151,7 @@ class SecretsManagerClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.98/reference/services/secretsmanager.html#SecretsManager.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/secretsmanager.html#SecretsManager.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client.html#generate_presigned_url)
         """
 
@@ -167,13 +168,13 @@ class SecretsManagerClient:
         RequireEachIncludedType: bool = None
     ) -> GetRandomPasswordResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.98/reference/services/secretsmanager.html#SecretsManager.Client.get_random_password)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/secretsmanager.html#SecretsManager.Client.get_random_password)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client.html#get_random_password)
         """
 
     def get_resource_policy(self, *, SecretId: str) -> GetResourcePolicyResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.98/reference/services/secretsmanager.html#SecretsManager.Client.get_resource_policy)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/secretsmanager.html#SecretsManager.Client.get_resource_policy)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client.html#get_resource_policy)
         """
 
@@ -181,7 +182,7 @@ class SecretsManagerClient:
         self, *, SecretId: str, VersionId: str = None, VersionStage: str = None
     ) -> GetSecretValueResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.98/reference/services/secretsmanager.html#SecretsManager.Client.get_secret_value)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/secretsmanager.html#SecretsManager.Client.get_secret_value)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client.html#get_secret_value)
         """
 
@@ -194,7 +195,7 @@ class SecretsManagerClient:
         IncludeDeprecated: bool = None
     ) -> ListSecretVersionIdsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.98/reference/services/secretsmanager.html#SecretsManager.Client.list_secret_version_ids)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/secretsmanager.html#SecretsManager.Client.list_secret_version_ids)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client.html#list_secret_version_ids)
         """
 
@@ -207,7 +208,7 @@ class SecretsManagerClient:
         SortOrder: SortOrderTypeType = None
     ) -> ListSecretsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.98/reference/services/secretsmanager.html#SecretsManager.Client.list_secrets)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/secretsmanager.html#SecretsManager.Client.list_secrets)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client.html#list_secrets)
         """
 
@@ -215,7 +216,7 @@ class SecretsManagerClient:
         self, *, SecretId: str, ResourcePolicy: str, BlockPublicPolicy: bool = None
     ) -> PutResourcePolicyResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.98/reference/services/secretsmanager.html#SecretsManager.Client.put_resource_policy)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/secretsmanager.html#SecretsManager.Client.put_resource_policy)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client.html#put_resource_policy)
         """
 
@@ -224,12 +225,12 @@ class SecretsManagerClient:
         *,
         SecretId: str,
         ClientRequestToken: str = None,
-        SecretBinary: Union[bytes, IO[bytes]] = None,
+        SecretBinary: Union[bytes, IO[bytes], StreamingBody] = None,
         SecretString: str = None,
         VersionStages: List[str] = None
     ) -> PutSecretValueResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.98/reference/services/secretsmanager.html#SecretsManager.Client.put_secret_value)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/secretsmanager.html#SecretsManager.Client.put_secret_value)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client.html#put_secret_value)
         """
 
@@ -237,7 +238,7 @@ class SecretsManagerClient:
         self, *, SecretId: str, RemoveReplicaRegions: List[str]
     ) -> RemoveRegionsFromReplicationResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.98/reference/services/secretsmanager.html#SecretsManager.Client.remove_regions_from_replication)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/secretsmanager.html#SecretsManager.Client.remove_regions_from_replication)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client.html#remove_regions_from_replication)
         """
 
@@ -249,13 +250,13 @@ class SecretsManagerClient:
         ForceOverwriteReplicaSecret: bool = None
     ) -> ReplicateSecretToRegionsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.98/reference/services/secretsmanager.html#SecretsManager.Client.replicate_secret_to_regions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/secretsmanager.html#SecretsManager.Client.replicate_secret_to_regions)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client.html#replicate_secret_to_regions)
         """
 
     def restore_secret(self, *, SecretId: str) -> RestoreSecretResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.98/reference/services/secretsmanager.html#SecretsManager.Client.restore_secret)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/secretsmanager.html#SecretsManager.Client.restore_secret)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client.html#restore_secret)
         """
 
@@ -268,7 +269,7 @@ class SecretsManagerClient:
         RotationRules: "RotationRulesTypeTypeDef" = None
     ) -> RotateSecretResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.98/reference/services/secretsmanager.html#SecretsManager.Client.rotate_secret)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/secretsmanager.html#SecretsManager.Client.rotate_secret)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client.html#rotate_secret)
         """
 
@@ -276,19 +277,19 @@ class SecretsManagerClient:
         self, *, SecretId: str
     ) -> StopReplicationToReplicaResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.98/reference/services/secretsmanager.html#SecretsManager.Client.stop_replication_to_replica)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/secretsmanager.html#SecretsManager.Client.stop_replication_to_replica)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client.html#stop_replication_to_replica)
         """
 
     def tag_resource(self, *, SecretId: str, Tags: List["TagTypeDef"]) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.98/reference/services/secretsmanager.html#SecretsManager.Client.tag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/secretsmanager.html#SecretsManager.Client.tag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client.html#tag_resource)
         """
 
     def untag_resource(self, *, SecretId: str, TagKeys: List[str]) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.98/reference/services/secretsmanager.html#SecretsManager.Client.untag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/secretsmanager.html#SecretsManager.Client.untag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client.html#untag_resource)
         """
 
@@ -299,11 +300,11 @@ class SecretsManagerClient:
         ClientRequestToken: str = None,
         Description: str = None,
         KmsKeyId: str = None,
-        SecretBinary: Union[bytes, IO[bytes]] = None,
+        SecretBinary: Union[bytes, IO[bytes], StreamingBody] = None,
         SecretString: str = None
     ) -> UpdateSecretResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.98/reference/services/secretsmanager.html#SecretsManager.Client.update_secret)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/secretsmanager.html#SecretsManager.Client.update_secret)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client.html#update_secret)
         """
 
@@ -316,7 +317,7 @@ class SecretsManagerClient:
         MoveToVersionId: str = None
     ) -> UpdateSecretVersionStageResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.98/reference/services/secretsmanager.html#SecretsManager.Client.update_secret_version_stage)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/secretsmanager.html#SecretsManager.Client.update_secret_version_stage)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client.html#update_secret_version_stage)
         """
 
@@ -324,11 +325,11 @@ class SecretsManagerClient:
         self, *, ResourcePolicy: str, SecretId: str = None
     ) -> ValidateResourcePolicyResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.98/reference/services/secretsmanager.html#SecretsManager.Client.validate_resource_policy)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/secretsmanager.html#SecretsManager.Client.validate_resource_policy)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client.html#validate_resource_policy)
         """
 
     def get_paginator(self, operation_name: Literal["list_secrets"]) -> ListSecretsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.98/reference/services/secretsmanager.html#SecretsManager.Paginator.ListSecrets)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/paginators.html#listsecretspaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/secretsmanager.html#SecretsManager.Paginator.ListSecrets)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/paginators.html#listsecretspaginator)
         """
