@@ -15,6 +15,8 @@ import sys
 from datetime import datetime
 from typing import IO, Dict, List, Union
 
+from botocore.response import StreamingBody
+
 from .literals import FilterNameStringTypeType, StatusTypeType
 
 if sys.version_info >= (3, 8):
@@ -152,7 +154,7 @@ GetSecretValueResponseTypeDef = TypedDict(
         "ARN": str,
         "Name": str,
         "VersionId": str,
-        "SecretBinary": Union[bytes, IO[bytes]],
+        "SecretBinary": Union[bytes, IO[bytes], StreamingBody],
         "SecretString": str,
         "VersionStages": List[str],
         "CreatedDate": datetime,
